For compse idea action in workflow, after it's done, it should support re-open.

when user click on the completed compose idea action, it should popup a model windown ask if want to open for editing.

after confirm open for editing:
1. the status should be in progress.
2. and composing modal window should be opened, user can update the folder name(linked idea should also be shown in composing idea tab with the folder point to the linked folder), and the editing area should load the idea file whatever it is.
3. the button name should change to update idea.
4. user can also choose to link a idea, which will just override the existing folder and idea.

